@@ -4,6 +4,11 @@ import sys
 
 supports_exec = True
 
+try:
+    import _winapi as win32
+except ImportError:  # pragma: no cover
+    win32 = None
+
 if sys.platform.startswith("java"):
     _billiard = None
 else:
@@ -18,7 +23,8 @@ else:
         from multiprocessing.connection import Connection  # noqa
 
     PipeConnection = getattr(_billiard, "PipeConnection", None)
-    win32 = getattr(_billiard, "win32", None)
+    if win32 is None:
+        win32 = getattr(_billiard, "win32", None)  # noqa
 
 
 def ensure_multiprocessing():
